package org.apache.bcel.classfile;

import java.io.IOException;
import java.io.DataOutputStream;

public class EnumElementValue extends ElementValue
{
    private final int typeIdx;
    private final int valueIdx;
    
    public EnumElementValue(final int type, final int typeIdx, final int valueIdx, final ConstantPool cpool) {
        super(type, cpool);
        if (type != 101) {
            throw new IllegalArgumentException("Only element values of type enum can be built with this ctor - type specified: " + type);
        }
        this.typeIdx = typeIdx;
        this.valueIdx = valueIdx;
    }
    
    @Override
    public void dump(final DataOutputStream dos) throws IOException {
        dos.writeByte(super.getType());
        dos.writeShort(this.typeIdx);
        dos.writeShort(this.valueIdx);
    }
    
    public String getEnumTypeString() {
        return super.getConstantPool().getConstantUtf8(this.typeIdx).getBytes();
    }
    
    public String getEnumValueString() {
        return super.getConstantPool().getConstantUtf8(this.valueIdx).getBytes();
    }
    
    public int getTypeIndex() {
        return this.typeIdx;
    }
    
    public int getValueIndex() {
        return this.valueIdx;
    }
    
    @Override
    public String stringifyValue() {
        return super.getConstantPool().getConstantUtf8(this.valueIdx).getBytes();
    }
}
